==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "활동",
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Your settings have been updated." : "설정이 업데이트 되었습니다.",
    "Mail" : "메일",
    "Stream" : "스트림",
    "Activities" : "활동",
    "Error loading activities" : "활동 불러오기 오류",
    "No activities" : "활동 없음",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Activity notification" : "활동 알림",
    "All Activities" : "모든 활동",
    "Activities by you" : "내 활동",
    "Activities by others" : "다른 사람의 활동",
    "\"remote user\"" : "\"원격 사용자\"",
    "in %s" : "%s",
    "%s and %s" : "%s, %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s 및 <strong %s>%n개 더</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s, %n개 더 있음"],
    "Hello %s," : "%s 님 안녕하세요,",
    "You are receiving this email because the following things happened at %s" : "%s에서 일어난 일의 알림을 받아 보기로 설정하였으므로 이 메일을 받았습니다",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 그 외 %n개 더 있음"],
    "Notifications" : "알림",
    "List your own actions in the stream" : "스트림에서 내가 한 작업 보기",
    "Notify about your own actions via email" : "내 작업도 이메일로 알림 받기",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send emails:" : "이메일 보내는 간격:",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Activity feed" : "활동 피드",
    "Enable RSS feed" : "RSS 피드 사용",
    "No activity yet" : "아직 활동 없음",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "Files" : "파일",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s 및 <strong class=\"has-tooltip\" title=\"%s\">%n개 더</strong>"]
},
"nplurals=1; plural=0;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "활동",
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Your settings have been updated." : "설정이 업데이트 되었습니다.",
    "Mail" : "메일",
    "Stream" : "스트림",
    "Activities" : "활동",
    "Error loading activities" : "활동 불러오기 오류",
    "No activities" : "활동 없음",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "\"remote user\"" : "\"원격 사용자\"",
    "Activity notification" : "활동 알림",
    "All Activities" : "모든 활동",
    "Activities by you" : "내 활동",
    "Activities by others" : "다른 사람의 활동",
    "%s and %s" : "%s, %s",
    "Hello %s," : "%s 님 안녕하세요,",
    "You are receiving this email because the following things happened at %s" : "%s에서 일어난 일의 알림을 받아 보기로 설정하였으므로 이 메일을 받았습니다",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 그 외 %n개 더 있음"],
    "List your own actions in the stream" : "스트림에서 내가 한 작업 보기",
    "Notify about your own actions via email" : "내 작업도 이메일로 알림 받기",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send emails:" : "이메일 보내는 간격:",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Activity feed" : "활동 피드",
    "Enable RSS feed" : "RSS 피드 사용",
    "No activity yet" : "아직 활동 없음",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "Files" : "파일"
},
"nplurals=1; plural=0;");
